@@ -17,6 +17,8 @@ from os import makedirs
 from pathlib import Path
 from time import time
 
+from inspyre_toolbox.live_timer.errors import TimerNotStartedError
+
 
 class TimerHistory(object):
 
@@ -53,8 +55,8 @@ class TimerHistory(object):
     def write(self):
         data_path = Path("~/Inspyre-Softworks/Inspyre-Toolbox/data").expanduser()
 
-        filename = "ledger_" + str(time()).split('.')[0]
-        filepath = str(str(data_path) + "/" + filename + ".txt")
+        filename = f'ledger_{str(time()).split(".")[0]}'
+        filepath = str(f'{str(data_path)}/{filename}.txt')
 
         filepath = str(Path(filepath).resolve())
 
@@ -64,6 +66,9 @@ class TimerHistory(object):
         with open(filepath, "w") as fp:
             fp.write(str(self.ledger))
 
+    def reset(self):
+        self.ledger = []
+
 
 def format_seconds_to_hhmmss(seconds):
     hours = seconds // (60 * 60)
@@ -98,9 +103,9 @@ class Timer(object):
         self.mark_2 = None
 
         # Start a Timer history object to track times for resets
-        self.history = TimerHistory(self.get_elapsed)
+        self.history = TimerHistory(self.__get_elapsed)
 
-    def get_elapsed(self, ts=None, sans_pause: bool = False, seconds=False):
+    def __get_elapsed(self, ts=None, sans_pause: bool = False, seconds=False):
         """
         
         Args:
@@ -111,11 +116,7 @@ class Timer(object):
         Returns:
 
         """
-        if ts is None:
-            diff_time = self.start_time
-        else:
-            diff_time = ts
-
+        diff_time = self.start_time if ts is None else ts
         self.mark_2 = time()
         # print(self.mark_2)
         # print(self.start_time)
@@ -133,10 +134,17 @@ class Timer(object):
         tpt += self.total_pause_time
         diff = diff - tpt
 
-        if seconds:
-            return diff
+        return diff if seconds else format_seconds_to_hhmmss(diff)
+
+    def get_elapsed(self, *args, **kwargs):
+        if self.is_running:
+            self.history.add("QUERY")
+            return self.__get_elapsed(*args, **kwargs)
         else:
-            return format_seconds_to_hhmmss(diff)
+            try:
+                raise TimerNotStartedError(skip_print=True)
+            except TimerNotStartedError as e:
+                print(e.message)
 
     def reset(self):
         """
@@ -145,7 +153,18 @@ class Timer(object):
 
         """
         self.history.add(action="RESET")
-        self.start()
+        self.was_paused = False
+        self.paused = False
+        self.total_pause_time = 0
+        self.pause_start = None
+        self.pause_end = None
+        self.started = False
+        self.mark_2 = None
+        
+    def restart(self):
+        self.reset()
+        if not self.started:
+            self.start()
 
     def start(self):
         """
@@ -156,6 +175,7 @@ class Timer(object):
         self.start_time = time()
         self.started = True
         self.history.add()
+        self.is_running = True
 
     def pause(self):
         """
@@ -170,12 +190,12 @@ class Timer(object):
 
         :return:
         """
-        if not self.paused:
-            self.pause_start = time()
-            self.paused = True
-            self.history.add("PAUSE")
-        else:
+        if self.paused:
             return False
+        self.pause_start = time()
+        self.paused = True
+        self.was_paused = True
+        self.history.add("PAUSE")
 
     def unpause(self):
         """
